# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: waChatLockSettings/WAProtobufsChatLockSettings.proto
# Protobuf Python Version: 4.25.3
"""Generated protocol buffer code."""

from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from waUserPassword import (
    WAProtobufsUserPassword_pb2 as waUserPassword_dot_WAProtobufsUserPassword__pb2,
)


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n4waChatLockSettings/WAProtobufsChatLockSettings.proto\x12\x1bWAProtobufsChatLockSettings\x1a,waUserPassword/WAProtobufsUserPassword.proto"f\n\x10\x43hatLockSettings\x12\x17\n\x0fhideLockedChats\x18\x01 \x01(\x08\x12\x39\n\nsecretCode\x18\x02 \x01(\x0b\x32%.WAProtobufsUserPassword.UserPasswordB.Z,go.mau.fi/whatsmeow/proto/waChatLockSettings'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(
    DESCRIPTOR, "waChatLockSettings.WAProtobufsChatLockSettings_pb2", _globals
)
if _descriptor._USE_C_DESCRIPTORS == False:
    _globals["DESCRIPTOR"]._options = None
    _globals[
        "DESCRIPTOR"
    ]._serialized_options = b"Z,go.mau.fi/whatsmeow/proto/waChatLockSettings"
    _globals["_CHATLOCKSETTINGS"]._serialized_start = 131
    _globals["_CHATLOCKSETTINGS"]._serialized_end = 233
# @@protoc_insertion_point(module_scope)
