# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: waReporting/WAWebProtobufsReporting.proto
# Protobuf Python Version: 4.25.3
"""Generated protocol buffer code."""

from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n)waReporting/WAWebProtobufsReporting.proto\x12\x17WAWebProtobufsReporting"d\n\nReportable\x12\x12\n\nminVersion\x18\x01 \x01(\r\x12\x12\n\nmaxVersion\x18\x02 \x01(\r\x12\x1f\n\x17notReportableMinVersion\x18\x03 \x01(\r\x12\r\n\x05never\x18\x04 \x01(\x08"\xa2\x01\n\x06\x43onfig\x12\x39\n\x05\x66ield\x18\x01 \x03(\x0b\x32*.WAWebProtobufsReporting.Config.FieldEntry\x12\x0f\n\x07version\x18\x02 \x01(\r\x1aL\n\nFieldEntry\x12\x0b\n\x03key\x18\x01 \x01(\r\x12-\n\x05value\x18\x02 \x01(\x0b\x32\x1e.WAWebProtobufsReporting.Field:\x02\x38\x01"\xf4\x01\n\x05\x46ield\x12\x12\n\nminVersion\x18\x01 \x01(\r\x12\x12\n\nmaxVersion\x18\x02 \x01(\r\x12\x1f\n\x17notReportableMinVersion\x18\x03 \x01(\r\x12\x11\n\tisMessage\x18\x04 \x01(\x08\x12>\n\x08subfield\x18\x05 \x03(\x0b\x32,.WAWebProtobufsReporting.Field.SubfieldEntry\x1aO\n\rSubfieldEntry\x12\x0b\n\x03key\x18\x01 \x01(\r\x12-\n\x05value\x18\x02 \x01(\x0b\x32\x1e.WAWebProtobufsReporting.Field:\x02\x38\x01\x42\'Z%go.mau.fi/whatsmeow/proto/waReportingb\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(
    DESCRIPTOR, "waReporting.WAWebProtobufsReporting_pb2", _globals
)
if _descriptor._USE_C_DESCRIPTORS == False:
    _globals["DESCRIPTOR"]._options = None
    _globals[
        "DESCRIPTOR"
    ]._serialized_options = b"Z%go.mau.fi/whatsmeow/proto/waReporting"
    _globals["_CONFIG_FIELDENTRY"]._options = None
    _globals["_CONFIG_FIELDENTRY"]._serialized_options = b"8\001"
    _globals["_FIELD_SUBFIELDENTRY"]._options = None
    _globals["_FIELD_SUBFIELDENTRY"]._serialized_options = b"8\001"
    _globals["_REPORTABLE"]._serialized_start = 70
    _globals["_REPORTABLE"]._serialized_end = 170
    _globals["_CONFIG"]._serialized_start = 173
    _globals["_CONFIG"]._serialized_end = 335
    _globals["_CONFIG_FIELDENTRY"]._serialized_start = 259
    _globals["_CONFIG_FIELDENTRY"]._serialized_end = 335
    _globals["_FIELD"]._serialized_start = 338
    _globals["_FIELD"]._serialized_end = 582
    _globals["_FIELD_SUBFIELDENTRY"]._serialized_start = 503
    _globals["_FIELD_SUBFIELDENTRY"]._serialized_end = 582
# @@protoc_insertion_point(module_scope)
