# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: waArmadilloICDC/WAArmadilloICDC.proto
# Protobuf Python Version: 4.25.3
"""Generated protocol buffer code."""

from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n%waArmadilloICDC/WAArmadilloICDC.proto\x12\x0fWAArmadilloICDC"_\n\x10ICDCIdentityList\x12\x0b\n\x03seq\x18\x01 \x01(\x05\x12\x11\n\ttimestamp\x18\x02 \x01(\x03\x12\x0f\n\x07\x64\x65vices\x18\x03 \x03(\x0c\x12\x1a\n\x12signingDeviceIndex\x18\x04 \x01(\x05"<\n\x16SignedICDCIdentityList\x12\x0f\n\x07\x64\x65tails\x18\x01 \x01(\x0c\x12\x11\n\tsignature\x18\x02 \x01(\x0c\x42+Z)go.mau.fi/whatsmeow/proto/waArmadilloICDC'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(
    DESCRIPTOR, "waArmadilloICDC.WAArmadilloICDC_pb2", _globals
)
if _descriptor._USE_C_DESCRIPTORS == False:
    _globals["DESCRIPTOR"]._options = None
    _globals[
        "DESCRIPTOR"
    ]._serialized_options = b"Z)go.mau.fi/whatsmeow/proto/waArmadilloICDC"
    _globals["_ICDCIDENTITYLIST"]._serialized_start = 58
    _globals["_ICDCIDENTITYLIST"]._serialized_end = 153
    _globals["_SIGNEDICDCIDENTITYLIST"]._serialized_start = 155
    _globals["_SIGNEDICDCIDENTITYLIST"]._serialized_end = 215
# @@protoc_insertion_point(module_scope)
